
# mince 🔪🧄🧅

toolkit for slicing up data into bite-sized dashboards

Steps for using mince:
1. ingest raw data into standardized format
2. define dashboard specification
3. serve dashboard
4. continually update the data

